#include "sql.hpp"

#include <cstdio>
#include <cstdlib>

#include <sqlite3.h>

const char create_table[] = "CREATE TABLE IF NOT EXISTS prim_table ( ID INTEGER PRIMARY KEY, GEN INTEGER, HASH INTEGER, POS INTEGER, LIKED INTEGER);";

const char create_index[] = "CREATE INDEX IF NOT EXISTS idx_id ON prim_table (ID);";

constexpr char DB_NAME[] = "data.db";

static int callback(void *NotUsed, int argc, char **argv, char **azColName)
{
  int i;
  for (i = 0; i < argc; i++)
  {
    printf("%s = %s\n", azColName[i], argv[i] ? argv[i] : "NULL");
  }
  printf("\n");
  return 0;
}

void sql::init()
{
  sqlite3_initialize();
  sqlite3 *db;
  char *zErrMsg = 0;
  int rc;

  /* Open database */
  rc = sqlite3_open(DB_NAME, &db);

  if (rc)
  {
    fprintf(stderr, "Can't open database: %s\n", sqlite3_errmsg(db));
    return;
  }
  else
  {
    fprintf(stdout, "Opened database successfully\n");
  }

  /* Execute SQL statement */
  rc = sqlite3_exec(db, create_table, callback, 0, &zErrMsg);

  if (rc != SQLITE_OK)
  {
    fprintf(stderr, "SQL error: %s\n", zErrMsg);
    sqlite3_free(zErrMsg);
  }
  else
  {
    fprintf(stdout, "Table created successfully\n");
  }

  /* Execute SQL statement */
  rc = sqlite3_exec(db, create_index, callback, 0, &zErrMsg);

  if (rc != SQLITE_OK)
  {
    fprintf(stderr, "SQL error: %s\n", zErrMsg);
    sqlite3_free(zErrMsg);
  }
  else
  {
    fprintf(stdout, "Index created successfully\n");
  }

  sqlite3_close(db);
}

void sql::shutdown()
{
  sqlite3_shutdown();
}